summaryrefslogtreecommitdiff
path: root/src/print.c
diff options
context:
space:
mode:
authorJim Blandy <jimb@redhat.com>1992-07-13 20:56:17 +0000
committerJim Blandy <jimb@redhat.com>1992-07-13 20:56:17 +0000
commit0137dbf747e9fcbfe6f37c7fb0bbb29012a27179 (patch)
tree658380474eae580fc6b03b724e6498d9cf0b783f /src/print.c
parentff11dfa15b3b56559bac0d5c6b0a26a80d2d5f6d (diff)
downloademacs-0137dbf747e9fcbfe6f37c7fb0bbb29012a27179.tar.gz
entered into RCS
Diffstat (limited to 'src/print.c')
-rw-r--r--src/print.c42
1 files changed, 21 insertions, 21 deletions
diff --git a/src/print.c b/src/print.c
index 534d5d67b22..4b707c1c24d 100644
--- a/src/print.c
+++ b/src/print.c
@@ -25,7 +25,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
#ifndef standalone
#include "buffer.h"
-#include "screen.h"
+#include "frame.h"
#include "window.h"
#include "process.h"
#include "dispextern.h"
@@ -159,7 +159,7 @@ glyph_to_str_cpy (glyphs, str)
#define PRINTCHAR(ch) printchar (ch, printcharfun)
/* Index of first unused element of SCREEN_MESSAGE_BUF(selected_screen). */
static int printbufidx;
static void
@@ -190,17 +190,17 @@ printchar (ch, fun)
return;
}
- if (echo_area_glyphs != SCREEN_MESSAGE_BUF (selected_screen)
+ if (echo_area_glyphs != FRAME_MESSAGE_BUF (selected_frame)
|| !message_buf_print)
{
- echo_area_glyphs = SCREEN_MESSAGE_BUF (selected_screen);
+ echo_area_glyphs = FRAME_MESSAGE_BUF (selected_frame);
printbufidx = 0;
message_buf_print = 1;
}
- if (printbufidx < SCREEN_WIDTH (selected_screen) - 1)
- SCREEN_MESSAGE_BUF (selected_screen)[printbufidx++] = ch;
- SCREEN_MESSAGE_BUF (selected_screen)[printbufidx] = 0;
+ if (printbufidx < FRAME_WIDTH (selected_frame) - 1)
+ FRAME_MESSAGE_BUF (selected_frame)[printbufidx++] = ch;
+ FRAME_MESSAGE_BUF (selected_frame)[printbufidx] = 0;
return;
}
@@ -242,19 +242,19 @@ strout (ptr, size, printcharfun)
return;
}
- if (echo_area_glyphs != SCREEN_MESSAGE_BUF (selected_screen)
+ if (echo_area_glyphs != FRAME_MESSAGE_BUF (selected_frame)
|| !message_buf_print)
{
- echo_area_glyphs = SCREEN_MESSAGE_BUF (selected_screen);
+ echo_area_glyphs = FRAME_MESSAGE_BUF (selected_frame);
printbufidx = 0;
message_buf_print = 1;
}
- if (i > SCREEN_WIDTH (selected_screen) - printbufidx - 1)
- i = SCREEN_WIDTH (selected_screen) - printbufidx - 1;
- bcopy (ptr, &SCREEN_MESSAGE_BUF (selected_screen) [printbufidx], i);
+ if (i > FRAME_WIDTH (selected_frame) - printbufidx - 1)
+ i = FRAME_WIDTH (selected_frame) - printbufidx - 1;
+ bcopy (ptr, &FRAME_MESSAGE_BUF (selected_frame) [printbufidx], i);
printbufidx += i;
- SCREEN_MESSAGE_BUF (selected_screen) [printbufidx] = 0;
+ FRAME_MESSAGE_BUF (selected_frame) [printbufidx] = 0;
return;
}
@@ -275,7 +275,7 @@ print_string (string, printcharfun)
Lisp_Object printcharfun;
{
if (EQ (printcharfun, Qnil) || EQ (printcharfun, Qt))
/* In predictable cases, strout is safe: output to buffer or screen. */
strout (XSTRING (string)->data, XSTRING (string)->size, printcharfun);
else
{
@@ -887,17 +887,17 @@ print (obj, printcharfun, escapeflag)
strout ("#<window-configuration>", -1, printcharfun);
break;
-#ifdef MULTI_SCREEN
- case Lisp_Screen:
- strout (((XSCREEN (obj)->display.nothing == 0)
- ? "#<dead screen " : "#<screen "),
+#ifdef MULTI_FRAME
+ case Lisp_Frame:
+ strout ((FRAME_LIVE_P (XFRAME (obj))
+ ? "#<frame " : "#<dead frame "),
-1, printcharfun);
- print_string (XSCREEN (obj)->name, printcharfun);
- sprintf (buf, " 0x%x", XFASTINT (XSCREEN (obj)));
+ print_string (XFRAME (obj)->name, printcharfun);
+ sprintf (buf, " 0x%x", XFASTINT (XFRAME (obj)));
strout (buf, -1, printcharfun);
strout (">", -1, printcharfun);
break;
-#endif /* MULTI_SCREEN */
+#endif /* MULTI_FRAME */
case Lisp_Marker:
strout ("#<marker ", -1, printcharfun);
@@ -159,7 +159,7 @@ glyph_to_str_cpy (glyphs, str)
#define PRINTCHAR(ch) printchar (ch, printcharfun)
-/* Index of first unused element of SCREEN_MESSAGE_BUF(selected_screen). */
+/* Index of first unused element of FRAME_MESSAGE_BUF(selected_frame). */
static int printbufidx;
static void
@@ -275,7 +275,7 @@ print_string (string, printcharfun)
{
if (EQ (printcharfun, Qnil) || EQ (printcharfun, Qt))
- /* In predictable cases, strout is safe: output to buffer or screen. */
+ /* In predictable cases, strout is safe: output to buffer or frame. */
strout (XSTRING (string)->data, XSTRING (string)->size, printcharfun);
else